deeplake.core.storage
=====================
.. currentmodule:: deeplake.core.storage

Base Storage Provider
~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: StorageProvider()
    :private-members:
    :special-members:
    :members:

LRU Cache
~~~~~~~~~
.. autoclass:: LRUCache()
    :show-inheritance:
    :private-members:
    :special-members:
    :members:

S3 Storage Provider
~~~~~~~~~~~~~~~~~~~
.. autoclass:: S3Provider()
    :show-inheritance:
    :special-members:
    :private-members:
    :members:

Google Cloud Storage Provider
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: GCSProvider()
    :show-inheritance:
    :special-members:
    :private-members:
    :members:

Google Drive Storage Provider
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: GDriveProvider()
    :show-inheritance:
    :special-members:
    :private-members:
    :members:

Local Storage Provider
~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: LocalProvider()
    :show-inheritance:
    :special-members:
    :private-members:
    :members:

Memory Provider
~~~~~~~~~~~~~~~
.. autoclass:: MemoryProvider()
    :show-inheritance:
    :special-members:
    :private-members:
    :members:
